# Utils

General utilities complimenting and expanding on standard python.

## Setup & Install

https://pypi.org/project/utils-nuuuwan/#history

```
pip install utils-nuuuwan
```

## Version History

### 1.0.29 (NEXT RELEASE)

### 1.0.38 (LATEST RELEASE)

* Added timezone logic to timex.format_time and parse_time
* Removed StopWatch
* Fixed propogate #BUG in logx.get_logger
* Added xmlx.render_link_styles

### 1.0.37

* Added defaults to colorx
* Added colorx with various random color generators
* Added basic latlng container
* Added ds.get_count

### 1.0.36

* Added printx with printing utils
* Added snake_to_camel and camel_to_snake to dt
* Added zipx - with basic Zip utils.

### 1.0.35

* Added xmlx, which contains various utils for manipulating xml

### 1.0.34
(No Release)

### 1.0.33

* Added logx. get_logger creates a custom logger that prints log messages in color
